@@ -1,22 +1,21 @@
-/***************************************************************************
- *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>           *
- *             (C) 2012 by Dan Vratil <dvratil@redhat.com>                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; see the file COPYING. If not, write to       *
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/*************************************************************************************
+ *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>                     *
+ *             (C) 2012, 2013 by Daniel Vrátil <dvratil@redhat.com>                  *
+ *                                                                                   *
+ *  This library is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU Lesser General Public                       *
+ *  License as published by the Free Software Foundation; either                     *
+ *  version 2.1 of the License, or (at your option) any later version.               *
+ *                                                                                   *
+ *  This library is distributed in the hope that it will be useful,                  *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
+ *  Lesser General Public License for more details.                                  *
+ *                                                                                   *
+ *  You should have received a copy of the GNU Lesser General Public                 *
+ *  License along with this library; if not, write to the Free Software              *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
+ *************************************************************************************/
 
 #include "edid.h"
 
@@ -58,6 +57,24 @@ class Edid::Private
       gamma(0)
     { }
 
+    Private(const Private &other):
+      valid(other.valid),
+      monitorName(other.monitorName),
+      vendorName(other.vendorName),
+      serialNumber(other.serialNumber),
+      eisaId(other.eisaId),
+      checksum(other.checksum),
+      pnpId(other.pnpId),
+      width(other.width),
+      height(other.height),
+      gamma(other.gamma),
+      red(other.red),
+      green(other.green),
+      blue(other.blue),
+      white(other.white)
+    {
+    }
+
     bool parse(const quint8 *data, size_t length);
     int edidGetBit(int in, int bit) const;
     int edidGetBits(int in, int begin, int end) const;
@@ -94,11 +111,22 @@ Edid::Edid(const quint8 *data, size_t length, QObject *parent)
     d->parse(data, length);
 }
 
+Edid::Edid(Edid::Private *dd)
+  : QObject()
+  , d(dd)
+{
+}
+
 Edid::~Edid()
 {
     delete d;
 }
 
+Edid *Edid::clone() const
+{
+    return new Edid(new Private(*d));
+}
+
 bool Edid::isValid() const
 {
     return d->valid;
